@@ -154,9 +154,12 @@ class __pdoc__(dict):
         return super().items()
 
 
-__all__ = ['Unit', 'arg', '__pdoc__']
-__all__ += [x for x, _ in sorted(_cache.units.items(), key=lambda x:x[1])]
+__all__ = [Unit.__name__, arg.__name__, '__pdoc__'] + [x for x, _ in sorted(_cache.units.items(), key=lambda x: x[1])]
 
 
 def __getattr__(name):
     return _cache[name]
+
+
+def __dir__():
+    return __all__
